// qsamplerAbout.h
//
/****************************************************************************
   Copyright (C) 2004-2005, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*****************************************************************************/

#ifndef __qsamplerAbout_h
#define __qsamplerAbout_h

#include "config.h"

#define QSAMPLER_TITLE        PACKAGE_NAME
#define QSAMPLER_VERSION      PACKAGE_VERSION

#define QSAMPLER_SUBTITLE     "A LinuxSampler Qt GUI Interface"
#define QSAMPLER_WEBSITE      "http://qsampler.sourceforge.net"
#define QSAMPLER_COPYRIGHT    "Copyright (C) 2004-2006, rncbc aka Rui Nuno Capela. All rights reserved."

#endif  // __qsamplerAbout_h

// end of qsamplerAbout.h
